@@ -7,19 +7,20 @@ var callBound = require('call-bind/callBound');
 var implementation = require('./implementation');
 var getPolyfill = require('./polyfill');
 var polyfill = getPolyfill();
+
 var shim = require('./shim');
 
 var $slice = callBound('Array.prototype.slice');
 
 // eslint-disable-next-line no-unused-vars
-var boundIndexOf = function indexOf(array, searchElement) {
+var bound = function indexOf(array, searchElement) {
 	RequireObjectCoercible(array);
 	return polyfill.apply(array, $slice(arguments, 1));
 };
-define(boundIndexOf, {
+define(bound, {
 	getPolyfill: getPolyfill,
 	implementation: implementation,
 	shim: shim
 });
 
-module.exports = boundIndexOf;
+module.exports = bound;
